const mysql = require("./mysql_db")
const logger = require('../logger')
var { db_config } = require('../../config/config.js')
const utils = require('../utils.js')


/**
 * 是否暂停归集动作
 */
async function isPause(type) {
    var sql = 'select * from remote_config WHERE type=? '
    var par = [type]
    logger.info('isPause', sql, par)
    return new Promise((resolve) => {
        mysql.getMySqlInstance().getConnection(function (err, connection) {
            if (err) {
                logger.error('isPause', err)
                logger.error('isPause', sql)
                resolve(null);
                return;
            }
            connection.query(
                sql, par,
                function selectCb(error, results) {
                    if (error) {
                        logger.error('isPause', error, sql, par)
                        resolve(1);
                        return;
                    }
                    logger.log('isPause ret=', error, results);
                    //用完当前连接需要释放,归还给连接池
                    connection.release();
                    if (results && Array.isArray(results) && results.length > 0) {
                        resolve(results[0].pause);
                    } else {
                        resolve(1);
                    }
                }
            );
        })
    })
}

/**
 * 过滤某些地址归集
 * collect_coins
 */
async function isBlackList(type, chain, address) {
    var sql = 'select * from blacklist WHERE type=? AND address=? AND status=1 AND chain=? '
    switch (chain) {
        case 'bsc_testnet':
        case 'bsc_mainnet':
            chain = 'bsc'
            break
        case 'czz':
        case 'CZZ':
            chain = 'czz'
            break
    }
    var par = [type, address, chain]
    logger.info('isBlackList', sql, par)
    return new Promise((resolve) => {
        mysql.getMySqlInstance().getConnection(function (err, connection) {
            if (err) {
                logger.error('isBlackList', err)
                logger.error('isBlackList', sql)
                resolve(null);
                return;
            }
            connection.query(
                sql, par,
                function selectCb(error, results) {
                    if (error) {
                        logger.error('isBlackList', error, sql, par)
                        resolve(null);
                        return;
                    }
                    logger.log('isBlackList ret=', error, results);
                    //用完当前连接需要释放,归还给连接池
                    connection.release();
                    if (results && Array.isArray(results) && results.length > 0) {
                        resolve(1);
                    } else {
                        resolve(0);
                    }
                }
            );
        })
    })
}






module.exports = {
    isPause,
    isBlackList,
}
